@@ -33,7 +33,7 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
             from spotPython.hyperparameters.values import (add_core_model_to_fun_control,
               get_default_hyperparameters_as_array)
             from spotPython.data.diabetes import Diabetes
-            from spotPython.hyperparameters.values import set_data_set
+            from spotPython.hyperparameters.values import set_control_key_value
             from spotPython.hyperparameters.values import (get_var_name, assign_values,
                 generate_one_config_from_var_dict)
             import spotPython.light.testmodel as tm
@@ -41,8 +41,9 @@ def test_model(config: dict, fun_control: dict) -> Tuple[float, float]:
                 _L_in=10,
                 _L_out=1,)
             dataset = Diabetes()
-            set_data_set(fun_control=fun_control,
-                            data_set=dataset)
+            set_control_key_value(control_dict=fun_control,
+                                    key="data_set",
+                                    value=dataset)
             add_core_model_to_fun_control(core_model=NetLightRegression,
                                         fun_control=fun_control,
                                         hyper_dict=LightHyperDict)
